@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -33,7 +33,7 @@ class Tag(SimpleEntity):
     """Use it to create tags for any object available in SOM.
 
     Doesn't have any other attribute than what is inherited from
-    :class:`~stalker.models.entity.SimpleEntity`
+    :class:`.SimpleEntity`
     """
     __auto_name__ = False
     __tablename__ = "Tags"
