@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -21,13 +21,14 @@
 import unittest2
 
 from sqlalchemy import Column, Integer, ForeignKey
-from stalker.models.mixins import StatusMixin
 from stalker.db.session import DBSession
+from stalker.models.mixins import StatusMixin
 from stalker.models.status import StatusList, Status
 
 # create a new mixed in SimpleEntity
 from stalker.models.entity import SimpleEntity
 
+
 class DeclStatMixA(SimpleEntity, StatusMixin):
     __tablename__ = "DeclStatMixAs"
     __mapper_args__ = {"polymorphic_identity": "DeclStatMixA"}
@@ -38,6 +39,7 @@ class DeclStatMixA(SimpleEntity, StatusMixin):
         super(DeclStatMixA, self).__init__(**kwargs)
         StatusMixin.__init__(self, **kwargs)
 
+
 class DeclStatMixB(SimpleEntity, StatusMixin):
     __tablename__ = "DeclStatMixBs"
     __mapper_args__ = {"polymorphic_identity": "DeclStatMixB"}
@@ -45,9 +47,10 @@ class DeclStatMixB(SimpleEntity, StatusMixin):
                   primary_key=True)
 
     def __init__(self, **kwargs):
-        super(B, self).__init__(**kwargs)
+        super(DeclStatMixB, self).__init__(**kwargs)
         StatusMixin.__init__(self, **kwargs)
 
+
 class StatusMixinTester(unittest2.TestCase):
     """tests StatusMixin
     """
@@ -55,7 +58,6 @@ class StatusMixinTester(unittest2.TestCase):
     def setUp(self):
         """setup the test
         """
-
         self.test_stat1 = Status(name="On Hold", code="OH")
         self.test_stat2 = Status(name="Work In Progress", code="WIP")
         self.test_stat3 = Status(name="Approved", code="APP")
@@ -76,7 +78,7 @@ class StatusMixinTester(unittest2.TestCase):
             "name": "ozgur",
             "status_list": self.test_a_statusList
         }
-    
+
     def tearDown(self):
         """clean up the test
         """
@@ -99,7 +101,6 @@ class StatusMixinTester(unittest2.TestCase):
     def test_status_list_working_properly(self):
         """testing if the status_list attribute is working properly
         """
-
         new_a_ins = DeclStatMixA(
             name="Ozgur",
             status_list=self.test_a_statusList
@@ -108,4 +109,3 @@ class StatusMixinTester(unittest2.TestCase):
         self.assertTrue(self.test_stat1 in new_a_ins.status_list)
         self.assertFalse(self.test_stat2 in new_a_ins.status_list)
         self.assertTrue(self.test_stat3 in new_a_ins.status_list)
-    
